.. _contributing:

============
Contributing
============

If you would like to contribute to the standard development, for example by:

- providing feedback on the existing drafts;
- suggesting changes to the standards;
- contributing to the development of reference implementation of validators code,

please send an e-mail to the authors of the openEPDA.org to d.pustakhod@tue.nl.

Please note that when contributing to openEPDA standards or code, you
agree to license your contribution under the same license as the rest of the
project.
